@@ -32,21 +32,5 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 
-
-class _Unset(object):
-    """An object to denote cases where a keyword argument is not set.
-    Useful in cases where None is a valid value for that argument as well."""
-    def __unicode__(self):
-        return "unset"
-
-    def __repr__(self):
-        return self.__unicode__()
-
-    def __nonzero__(self):
-        return False
-
-    def __len__(self):
-        return 0
-
-
-unset = _Unset()
+# null-related functionality moved to an external package
+from null import Null, NullDict, NullList, nullify, unset
